<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * CustomCourseMenu Block Helper - Events
 *
 * @package    block_custom_course_menu
 * @copyright  2015 onwards University of Portland (www.up.edu)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

if ($CFG->version < 2015111600) { // If not using Moodle 3.0+.
    $mapper = function($event) {
        return array(
            'handlerfile' => '/blocks/custom_course_menu/handler.php',
            'handlerfunction' => array('custom_course_menu_handler', $event),
            'schedule' => 'instant',
        );
    };

    $events = array(
        'course_deleted',
        'course_category_deleted',
        'user_deleted',
    );

    $handlers = array_combine($events, array_map($mapper, $events));
    exit;
}

// Events 2.1 API version.
$observers = array (
    array (
        'eventname' => '\core\event\course_deleted',
        'callback'  => 'block_custom_course_menu\observers::course_deleted',
    ),
    array (
        'eventname' => '\core\event\course_category_deleted',
        'callback'  => 'block_custom_course_menu\observers::course_category_deleted',
    ),
    array (
        'eventname' => '\core\event\user_deleted',
        'callback'  => 'block_custom_course_menu\observers::user_deleted',
    ),
);
